"use strict";
var LruCacheModule_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.LruCacheModule = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const constants_1 = require("./constants");
const providers_1 = require("./providers");
/**
 * LRU cache module.
 *
 * Must be registered using on of the following static methods:
 * - `register` - Registers the module synchronously.
 * - `registerAsync` - Registers the module asynchronously.
 */
let LruCacheModule = LruCacheModule_1 = class LruCacheModule {
    /**
     * Registers the LRU cache module synchronously.
     *
     * @param options LRU cache options.
     */
    static register(options) {
        const optionsProvider = {
            provide: constants_1.LRU_CACHE_OPTIONS,
            useValue: options
        };
        return {
            global: options.isGlobal,
            module: LruCacheModule_1,
            providers: [optionsProvider, providers_1.LruCache],
            exports: [providers_1.LruCache]
        };
    }
    /**
     * Registers the LRU cache module asynchronously.
     *
     * Requires one of the following factories: `useFactory`, `useClass`, or `useExisting`.
     *
     * @param options LRU cache async options.
     */
    static registerAsync(options) {
        var _a;
        return {
            global: options.isGlobal,
            imports: (_a = options.imports) !== null && _a !== void 0 ? _a : [],
            module: LruCacheModule_1,
            providers: [...LruCacheModule_1._createOptionsProviders(options), providers_1.LruCache],
            exports: [providers_1.LruCache]
        };
    }
    static _createOptionsProviders(options) {
        if (options.useExisting || options.useFactory) {
            return [LruCacheModule_1._createOptionsProvider(options)];
        }
        return [
            LruCacheModule_1._createOptionsProvider(options),
            {
                provide: options.useClass,
                useClass: options.useClass
            }
        ];
    }
    static _createOptionsProvider(options) {
        var _a, _b;
        if (options.useFactory) {
            return {
                provide: constants_1.LRU_CACHE_OPTIONS,
                useFactory: options.useFactory,
                inject: (_a = options.inject) !== null && _a !== void 0 ? _a : []
            };
        }
        return {
            provide: constants_1.LRU_CACHE_OPTIONS,
            useFactory: (factory) => tslib_1.__awaiter(this, void 0, void 0, function* () { return yield factory.createLruCacheOptions(); }),
            inject: [(_b = options.useExisting) !== null && _b !== void 0 ? _b : options.useClass]
        };
    }
};
LruCacheModule = LruCacheModule_1 = tslib_1.__decorate([
    (0, common_1.Module)({})
], LruCacheModule);
exports.LruCacheModule = LruCacheModule;
//# sourceMappingURL=lru-cache.module.js.map