import * as LRUCache from 'lru-cache';
import { type GetOptions, type PeekOptions, type SetOptions } from 'lru-cache';
import { LruCacheOptions } from '../interfaces';
/**
 * LRU cache service.
 *
 * Allows you to specify <K, V> (key, value) type parameters.
 */
export declare class LruCache<K = any, V = any> extends LRUCache<K, V> {
    private readonly _options;
    /** @internal */
    constructor(_options: LruCacheOptions);
    /**
     * Returns a value from the cache.
     *
     * If the key is not found, `get()` will return `undefined`.
     * This can be confusing when setting values specifically to `undefined`, as in `set(key, undefined)`. Use `has()`
     * to determine whether a key is present in the cache at all.
     */
    get<T = V>(key: K, options?: GetOptions): T | undefined;
    /**
     * Like `get()` but doesn't update recency or delete stale items.
     *
     * Returns `undefined` if the item is stale, unless `allowStale` is set either on the cache or in the options object.
     */
    peek<T = V>(key: K, options?: PeekOptions): T | undefined;
    /**
     * Adds a value to the cache.
     *
     * The third parameter can be either a TTL number, or options object.
     */
    set(key: K, value: V, ttl?: number): this;
    set(key: K, value: V, options?: SetOptions<K, V>): this;
    /**
     * Find a value for which the supplied callback function returns a truthy value, similar to `Array.find()`.
     *
     * The function is called as `fn(value, key, cache)`.
     */
    find<T = V>(callbackFn: (value: V, key: K, cache: this) => void | boolean | undefined, options?: GetOptions): T;
}
//# sourceMappingURL=lru-cache.d.ts.map