"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LruCache = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const LRUCache = require("lru-cache");
const constants_1 = require("../constants");
/**
 * LRU cache service.
 *
 * Allows you to specify <K, V> (key, value) type parameters.
 */
let LruCache = class LruCache extends LRUCache {
    /** @internal */
    constructor(_options) {
        super(_options);
        this._options = _options;
    }
    /**
     * Returns a value from the cache.
     *
     * If the key is not found, `get()` will return `undefined`.
     * This can be confusing when setting values specifically to `undefined`, as in `set(key, undefined)`. Use `has()`
     * to determine whether a key is present in the cache at all.
     */
    get(key, options) {
        return super.get(key, options);
    }
    /**
     * Like `get()` but doesn't update recency or delete stale items.
     *
     * Returns `undefined` if the item is stale, unless `allowStale` is set either on the cache or in the options object.
     */
    peek(key, options) {
        return super.peek(key, options);
    }
    set(key, value, optionsOrTtl) {
        optionsOrTtl = typeof optionsOrTtl === 'number' ? { ttl: optionsOrTtl } : optionsOrTtl;
        super.set(key, value, optionsOrTtl);
        return this;
    }
    /**
     * Find a value for which the supplied callback function returns a truthy value, similar to `Array.find()`.
     *
     * The function is called as `fn(value, key, cache)`.
     */
    find(
    // eslint-disable-next-line @typescript-eslint/no-invalid-void-type
    callbackFn, options) {
        return super.find(callbackFn, options);
    }
};
LruCache = tslib_1.__decorate([
    (0, common_1.Injectable)(),
    tslib_1.__param(0, (0, common_1.Inject)(constants_1.LRU_CACHE_OPTIONS)),
    tslib_1.__metadata("design:paramtypes", [Object])
], LruCache);
exports.LruCache = LruCache;
//# sourceMappingURL=lru-cache.js.map